@@ -113,6 +113,7 @@ void TabBar::removeTab(const int index, const bool &remainState)
         setCurrentIndex(index);
     else
         setCurrentIndex(count() - 1);
+
     emit tabAddableChanged(count() < kMaxTabCount);
 
     if (count() < 2) {
@@ -168,10 +169,12 @@ void TabBar::setCurrentIndex(const int index)
 void TabBar::setCurrentUrl(const QUrl &url)
 {
     Tab *tab = currentTab();
-    if (!tab)
+    if (tab == nullptr)
         createTab();
 
-    tab->setCurrentUrl(url);
+    tab = currentTab();
+    if (tab)
+        tab->setCurrentUrl(url);
 }
 
 void TabBar::closeTab(quint64 winId, const QUrl &url)
@@ -190,9 +193,12 @@ void TabBar::closeTab(quint64 winId, const QUrl &url)
         if (closeable || DFMBASE_NAMESPACE::UniversalUtils::urlEquals(curUrl, url) || url.isParentOf(curUrl)) {
             if (count() == 1) {
                 QUrl redirectToWhenDelete;
-                if (isMountedDevPath(url) || url.scheme() != Global::Scheme::kFile) {
+                if (isMountedDevPath(url)) {
                     redirectToWhenDelete = kGotoWhenDevRemoved;
-                } else {   // redirect to upper directory
+                } else if (dpfHookSequence->run("dfmplugin_workspace", "hook_Tab_FileDeleteNotCdComputer", curUrl, &redirectToWhenDelete)) {
+                    if (!redirectToWhenDelete.isValid())
+                        redirectToWhenDelete = kGotoWhenDevRemoved;
+                } else if (url.scheme() == Global::Scheme::kFile){   // redirect to upper directory
                     QString localPath = url.path();
                     do {
                         QStringList pathFragment = localPath.split("/");
@@ -223,6 +229,8 @@ void TabBar::closeTab(quint64 winId, const QUrl &url)
                         if (kGvfsMpts.contains(localPath))
                             redirectToWhenDelete = kGotoWhenDevRemoved;
                     }
+                } else {
+                    redirectToWhenDelete = kGotoWhenDevRemoved;
                 }
 
                 dpfSignalDispatcher->publish(GlobalEventType::kChangeCurrentUrl, winId, redirectToWhenDelete);
@@ -275,8 +283,11 @@ void TabBar::onMoveNext(Tab *tab)
     int tabIndex = tabList.indexOf(tab);
     if (tabIndex >= count() - 1)
         return;
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     tabList.swap(tabIndex, tabIndex + 1);
+#else
+    tabList.swapItemsAt(tabIndex, tabIndex + 1);
+#endif
 
     ++tabIndex;
     quint64 thisWinID = WorkspaceHelper::instance()->windowId(qobject_cast<QWidget *>(parent()));
@@ -292,8 +303,11 @@ void TabBar::onMovePrevius(Tab *tab)
     if (tabIndex <= 0)
         return;
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     tabList.swap(tabIndex, tabIndex - 1);
-
+#else
+    tabList.swapItemsAt(tabIndex, tabIndex - 1);
+#endif
     --tabIndex;
     quint64 thisWinID = WorkspaceHelper::instance()->windowId(qobject_cast<QWidget *>(parent()));
     WorkspaceEventCaller::sendTabMoved(thisWinID, tabIndex + 1, tabIndex);
@@ -432,7 +446,7 @@ void TabBar::mouseMoveEvent(QMouseEvent *event)
         tabCloseButton->setClosingIndex(closingIndex);
         int btnSize = height() > kTabHeightScaling ? kCloseButtonBigSize : kCloseButtonSmallSize;
         tabCloseButton->setSize(btnSize);
-        tabCloseButton->setPos(tab->x() + tab->width() - btnSize - 4, (btnSize - kCloseButtonSmallSize)/2 - 1);
+        tabCloseButton->setPos(tab->x() + tab->width() - btnSize - 4, (btnSize - kCloseButtonSmallSize) / 2 - 1);
 
         if (closingIndex == currentIndex)
             tabCloseButton->setActiveWidthTab(true);
@@ -585,7 +599,7 @@ void TabBar::handleTabAnimationFinished(const int index)
         Tab *tab = tabList.at(index);
         int btnSize = height() > kTabHeightScaling ? kCloseButtonBigSize : kCloseButtonSmallSize;
         tabCloseButton->setSize(btnSize);
-        tabCloseButton->setPos(tab->x() + tab->width() - btnSize - 4, (btnSize - kCloseButtonSmallSize)/2 - 1);
+        tabCloseButton->setPos(tab->x() + tab->width() - btnSize - 4, (btnSize - kCloseButtonSmallSize) / 2 - 1);
     }
 
     if ((tabCloseButton->getClosingIndex() >= count()
